# Build Status 

[![Release_Date](https://anaconda.org/pyiron/pyiron/badges/latest_release_date.svg)](https://anaconda.org/pyiron/pyiron)
[![Build Status](https://img.shields.io/travis/pyiron/pyiron/master.svg?label=Travis%20CI)](https://travis-ci.org/pyiron/pyiron)
[![Build status](https://img.shields.io/appveyor/ci/pyiron-runner/pyiron/master.svg?label=AppVeyor%20CI)](https://ci.appveyor.com/project/pyiron-runner/pyiron/branch/master)
_Anaconda_
[![Downloads](https://anaconda.org/pyiron/pyiron/badges/downloads.svg)](https://anaconda.org/pyiron/pyiron)

# Sub modules build status  

|    **Submodule**    |                   **Travis CI**                   |                      **AppVeyor**                     |
|:-------------------:|:-------------------------------------------------:|:-----------------------------------------------------:|
|    [pyiron_base]    |       [![][base_travis_build]][base_travis]       |       [![][base_appveyor_build]][base_appveyor]       |
| [pyiron_atomistics] | [![][atomistics_travis_build]][atomistics_travis] | [![][atomistics_appveyor_build]][atomistics_appveyor] |
|     [pyiron_dft]    |        [![][dft_travis_build]][dft_travis]        |        [![][dft_appveyor_build]][dft_appveyor]        |
|   [pyiron_example]  |    [![][example_travis_build]][example_travis]    |    [![][example_appveyor_build]][example_appveyor]    |
|   [pyiron_lammps]   |     [![][lammps_travis_build]][lammps_travis]     |     [![][lammps_appveyor_build]][lammps_appveyor]     |
|    [pyiron_vasp]    |       [![][vasp_travis_build]][vasp_travis]       |       [![][vasp_appveyor_build]][vasp_appveyor]       |

[pyiron_base]: https://github.com/pyiron/pyiron_base
[pyiron_atomistics]: https://github.com/pyiron/pyiron_atomistics
[pyiron_dft]: https://github.com/pyiron/pyiron_dft
[pyiron_example]: https://github.com/pyiron/pyiron_example_job
[pyiron_lammps]: https://github.com/pyiron/pyiron_lammps
[pyiron_vasp]: https://github.com/pyiron/pyiron_vasp

[base_travis_build]: https://travis-ci.org/pyiron/pyiron_base.svg?branch=master
[base_travis]: https://travis-ci.org/pyiron/pyiron_base
[atomistics_travis_build]: https://travis-ci.org/pyiron/pyiron_atomistics.svg?branch=master
[atomistics_travis]: https://travis-ci.org/pyiron/pyiron_atomistics
[dft_travis_build]: https://travis-ci.org/pyiron/pyiron_dft.svg?branch=master
[dft_travis]: https://travis-ci.org/pyiron/pyiron_dft
[example_travis_build]: https://travis-ci.org/pyiron/pyiron_example_job.svg?branch=master
[example_travis]: https://travis-ci.org/pyiron/pyiron_example_job
[lammps_travis_build]: https://travis-ci.org/pyiron/pyiron_lammps.svg?branch=master
[lammps_travis]: https://travis-ci.org/pyiron/pyiron_lammps
[vasp_travis_build]: https://travis-ci.org/pyiron/pyiron_vasp.svg?branch=master
[vasp_travis]: https://travis-ci.org/pyiron/pyiron_vasp

[base_appveyor_build]: https://ci.appveyor.com/api/projects/status/c9w3tjyffnw1d47x/branch/master?svg=true
[base_appveyor]: https://ci.appveyor.com/project/pyiron-runner/pyiron-base/branch/master
[atomistics_appveyor_build]: https://ci.appveyor.com/api/projects/status/57f61ea4t01l1rqg/branch/master?svg=true
[atomistics_appveyor]: https://ci.appveyor.com/project/pyiron-runner/pyiron-atomistics/branch/master
[dft_appveyor_build]: https://ci.appveyor.com/api/projects/status/tu2owtwrmjsh98yr/branch/master?svg=true
[dft_appveyor]: https://ci.appveyor.com/project/pyiron-runner/pyiron-dft/branch/master
[example_appveyor_build]: https://ci.appveyor.com/api/projects/status/4gs490vgif1bl0v5/branch/master?svg=true
[example_appveyor]: https://ci.appveyor.com/project/pyiron-runner/pyiron-example-job/branch/master
[lammps_appveyor_build]: https://ci.appveyor.com/api/projects/status/hhcy3dmjy6ffdy53/branch/master?svg=true
[lammps_appveyor]: https://ci.appveyor.com/project/pyiron-runner/pyiron-lammps/branch/master
[vasp_appveyor_build]: https://ci.appveyor.com/api/projects/status/h7w6b1m3pd7hc4n9/branch/master?svg=true
[vasp_appveyor]: https://ci.appveyor.com/project/pyiron-runner/pyiron-vasp/branch/master
